@@ -29,31 +29,7 @@ class LGBMOOF(OOF):
             sample_weight=w_train,
             eval_sample_weight=[w_train, w_valid]  # 与eval_set一致
         )
-
-    # def fit_predict(self, X_train, y_train, w_train, X_valid, y_valid, w_valid, X_test, **kwargs):
-    #     import lightgbm as lgb
-    #
-    #     estimator = lgb.__getattribute__(f'LGBM{self.task}')()  # 实例
-    #     estimator.set_params(**self.params)
-    #
-    #     fit_params = dict(
-    #         eval_set=[(X_train, y_train), (X_valid, y_valid)],
-    #         eval_metric=None,
-    #         eval_names=('Train🔥', 'Valid'),
-    #         verbose=100,
-    #         early_stopping_rounds=100,
-    #         sample_weight=w_train,
-    #         eval_sample_weight=[w_train, w_valid]  # 与eval_set一致
-    #     )
-    #
-    #     estimator.fit(
-    #         X_train, y_train,
-    #         **{**fit_params, **self.fit_params}  # fit_params
-    #     )
-    #
-    #     self._estimators.append(estimator)
-    #     predict = self._predict(estimator)
-    #     return map(predict, (X_valid, X_test))
+        return estimator, fit_params
 
 
 class XGBOOF(OOF):
